
## Fedora review:
# http://bugzilla.redhat.com/194375

Summary: K Desktop Environment - Utilities
Name: 	 kdeutils
Group:	 User Interface/Desktops

Epoch:	 6
Version: 3.5.6
Release: 1%{?dist}

License: GPL
URL:     http://www.kde.org/
Source0: ftp://ftp.kde.org/pub/kde/stable/%{version}/src/%{name}-%{version}.tar.bz2
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires: kdelibs-devel >= 6:%{version}
BuildRequires: desktop-file-utils
BuildRequires: gmp-devel
BuildRequires: python-devel python 
%if 0%{?fedora} > 4 || 0%{?rhel} > 4
BuildRequires: libXtst-devel
%endif
BuildRequires: net-snmp-devel
BuildRequires: xmms-devel

Requires: kdelibs >= 6:%{version}
Requires(post):   xdg-utils
Requires(postun): xdg-utils

Patch1: kdeutils-3.0.2-kdf-label.patch

# kdessh
Requires(hint): openssh-clients
# ark
Requires(hint): tar unzip zip gzip bzip2

# superkaramba used to be in Extras
%define superkaramba_ver 0.39
Obsoletes: superkaramba < 0:%{superkaramba_ver}
Provides:  superkaramba = 0:%{superkaramba_ver}

%description
Utilities for the K Desktop Environment.
Includes: ark (tar/gzip archive manager); kcalc (scientific calculator);
kcharselect (character selector); kdepasswd (change password);
kdessh (ssh front end); kdf (view disk usage); kedit (simple text editor);
kfloppy (floppy formatting tool); kgpg (gpg gui) ; khexedit (hex editor); 
kjots (note taker); klaptopdaemon (battery monitoring (etc) for laptops);
ksim (system information monitor); ktimer (task scheduler);

%package devel
Summary: Development files for %{name} 
Group:	 Development/Libraries
Requires: %{name} = %{epoch}:%{version}-%{release}
Requires: kdelibs-devel 
# legacy
#Obsoletes: kregexpeditor-devel < %{epoch}:%{version}-%{release}
%description devel
%{summary}.


%prep
%setup -q -n %{name}-%{version}%{?beta}

%patch1 -p1 -b .kdf-label


%build
unset QTDIR || : ; source /etc/profile.d/qt.sh

%configure \
  --includedir=%{_includedir}/kde \
  --disable-rpath \
  --disable-gcc-hidden-visibility \
  --enable-new-ldflags \
  --disable-debug --disable-warnings \
  --disable-dependency-tracking --enable-final \
  --with-extra-libs=%{_libdir} \
  --with-snmp \
  --with-xmms

make %{?_smp_mflags} PYTHON=%{__python}


%install
rm -rf $RPM_BUILD_ROOT

make install DESTDIR=$RPM_BUILD_ROOT PYTHON=%{__python}

desktop-file-install --vendor="" \
  --dir $RPM_BUILD_ROOT%{_datadir}/applications/kde \
  --add-category="Qt" \
  --add-category="KDE" \
  --add-category="Utility" \
  --delete-original \
  $RPM_BUILD_ROOT%{_datadir}/applnk/Utilities/*.desktop

## File lists
# locale's
%find_lang %{name} || touch %{name}.lang
# HTML (1.0)
HTML_DIR=$(kde-config --expandvars --install html)
if [ -d $RPM_BUILD_ROOT$HTML_DIR ]; then
for lang_dir in $RPM_BUILD_ROOT$HTML_DIR/* ; do
  if [ -d $lang_dir ]; then
    lang=$(basename $lang_dir)
    echo "%lang($lang) $HTML_DIR/$lang/*" >> %{name}.lang
    # replace absolute symlinks with relative ones
    pushd $lang_dir
      for i in *; do
        [ -d $i -a -L $i/common ] && rm -f $i/common && ln -sf ../common $i/common
      done
    popd
  fi
done  
fi  

# rpmdocs
for dir in ark k* superkaramba ; do
  for file in AUTHORS ChangeLog README TODO ; do
    test -s  "$dir/$file" && install -p -m644 -D "$dir/$file" "rpmdocs/$dir/$file"
  done
done

# Unpackaged files
rm -f $RPM_BUILD_ROOT%{_libdir}/lib{kcmlaptop,khexeditcommon,kmilo,kregexpeditorcommon,ksimcore}.la


%post
/sbin/ldconfig ||:
%{_bindir}/xdg-icon-resource forceupdate --theme crystalsvg 2> /dev/null || :
%{_bindir}/xdg-icon-resource forceupdate --theme hicolor 2> /dev/null || :
%{_bindir}/xdg-icon-resource forceupdate --theme locolor 2> /dev/null || :
%{_bindir}/xdg-desktop-menu forceupdate 2> /dev/null || :

%postun
/sbin/ldconfig ||:
%{_bindir}/xdg-icon-resource forceupdate --theme crystalsvg 2> /dev/null || :
%{_bindir}/xdg-icon-resource forceupdate --theme hicolor 2> /dev/null || :
%{_bindir}/xdg-icon-resource forceupdate --theme locolor 2> /dev/null || :
%{_bindir}/xdg-desktop-menu forceupdate 2> /dev/null || :


%files -f %{name}.lang
%defattr(-,root,root,-)
%doc AUTHORS README COPYING
%doc rpmdocs/*
%{_bindir}/*
%{_datadir}/icons/crystalsvg/*/*/*
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/icons/locolor/*/*/*
%{_datadir}/apps/*
%config %{_datadir}/config*/*
%{_datadir}/service*/*
%{_datadir}/applications/kde/*.desktop
%{_datadir}/autostart/*
%{_datadir}/mimelnk/*/*.desktop
%{_libdir}/kde3/*.[ls][ao]
%{_libdir}/lib*.so.*
# loadable modules, not shared libs!
%{_libdir}/libkdeinit_*.[ls][ao]
%{_libdir}/libkcm*.[ls][ao]

%files devel
%defattr(-,root,root,-)
%{_includedir}/kde/*
%{_libdir}/lib*.so
%exclude %{_libdir}/libkdeinit_*.so
%exclude %{_libdir}/libkcm*.so


%clean   
rm -rf $RPM_BUILD_ROOT


%changelog
* Tue Jan 16 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 6:3.5.6-1
- kde-3.5.6

* Mon Jan 08 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 6:3.5.5-2
- %%description: +kgpg 
- drop uber-old legacy Obsoletes/Provides

* Wed Oct 11 2006 Rex Dieter <rexdieter[AT]users.sf.net> 6:3.5.5-1
- kde-3.5.5

* Tue Jul 25 2006 Rex Dieter <rexdieter[AT]users.sf.net> 6:3.5.4-1
- kde-3.5.4
- add missing URL tag

* Mon Jun 19 2006 Rex Dieter <rexdieter[AT]users.sf.net> 6:3.5.3-3
- move %%_libdir/lib{kcm,kdeinit_}*.* bits to main pkg

* Wed Jun 07 2006 Rex Dieter <rexdieter[AT]users.sf.net> 6:3.5.3-2
- cleanup for Extras
- %%doc: COPYING, app docs (README, TODO, etc...)
- follow icon spec
- BR: desktop-file-utils
- use *versioned* Obsoletes/Provides tags
- drop old(!) legacy Obsoletes

* Mon Jun 05 2006 Than Ngo <than@redhat.com> 6:3.5.3-1
- update to 3.5.3

* Tue May 16 2006 Than Ngo <than@redhat.com> 6:3.5.2-2
- fix #192003, Missing BuildRequire on python-devel/libXtst-devel

* Wed Apr 05 2006 Than Ngo <than@redhat.com> 6:3.5.2-1
- update to 3.5.2

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 6:3.5.1-1.2
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 6:3.5.1-1.1
- rebuilt for new gcc4.1 snapshot and glibc changes

* Sun Feb 05 2006 Than Ngo <than@redhat.com> 6:3.5.1-1 
- 3.5.1

* Mon Jan 16 2006 Than Ngo <than@redhat.com> 6:3.5.0-4
- apply patch to fix #176463

* Thu Jan 05 2006 Radek Vokal <rvokal@redhat.com> 6:3.5.0-3
- rebuilt against new libnetsnmp

* Tue Dec 20 2005 Than Ngo <than@redhat.com> 6:3.5.0-2
- fix file conflict with superkaramba #176044 

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Wed Nov 30 2005 Than Ngo <than@redhat.com> 6:3.5.0-1
- 3.5

* Wed Nov 09 2005 Than Ngo <than@redhat.com> 6:3.4.92-4 
- rebuilt against new openssl
  
* Thu Nov 03 2005 Than Ngo <than@redhat.com> 6:3.4.92-3 
- rebuilt against new net-snmp

* Fri Oct 28 2005 Than Ngo <than@redhat.com> 6:3.4.92-2
- apply patch to initialize correctly the variables

* Tue Oct 25 2005 Than Ngo <than@redhat.com> 6:3.4.92-1
- update to 3.5 beta2

* Wed Oct 12 2005 Than Ngo <than@redhat.com> 6:3.4.91-3
- remove unneeded libacl-devel buildrequirement

* Tue Oct 11 2005 Karsten Hopp <karsten@redhat.de> 3.4.91-2
- add libacl-devel buildrequirement

* Fri Sep 30 2005 Than Ngo <than@redhat.com> 6:3.4.91-1
- update to 3.5 beta1

* Thu Sep 08 2005 Than Ngo <than@redhat.com> 6:3.4.2-2
- backport upstream patch to support /sys/power/state interface, #135623

* Thu Aug 11 2005 Than Ngo <than@redhat.com> 6:3.4.2-1
- update to 3.4.2

* Thu Jun 16 2005 Than Ngo <than@redhat.com> 6:3.4.1-1
- 3.4.1

* Fri Mar 18 2005 Than Ngo <than@redhat.com> 6:3.4.0-1
- 3.4.0

* Fri Mar 04 2005 Than Ngo <than@redhat.com> 6:3.4.0-0.rc1.2
- rebuilt against gcc-4.0.0-0.31

* Tue Mar 01 2005 Than Ngo <than@redhat.com> 6:3.4.0-0.rc1.1
- KDE 3.4.0 rc1

* Mon Feb 21 2005 Than Ngo <than@redhat.com> 6:3.3.92-0.1 
- KDE-3.4 beta2

* Tue Feb 08 2005 Than Ngo <than@redhat.com> 6:3.3.2-0.2
- add buildrequires on net-snmp-devel for ksim #147390

* Sun Dec 05 2004 Than Ngo <than@redhat.com> 6:3.3.2-0.1
- update to 3.3.2
- get rid of kdeutils-3.3.1-kdf-locale.patch, it's included in 3.3.2

* Wed Oct 27 2004 Than Ngo <than@redhat.com> 6:3.3.1-4
- fc4 rebuilt

* Wed Oct 27 2004 Than Ngo <than@redhat.com> 6:3.3.1-3
- rhel rebuilt

* Wed Oct 27 2004 Than Ngo <than@redhat.com> 6:3.3.1-2.1
- Fix translation issue bug #136437

* Fri Oct 15 2004 Than Ngo <than@redhat.com> 6:3.3.1-2
- fix uninitialsed variable

* Wed Oct 13 2004 Than Ngo <than@redhat.com> 6:3.3.1-1
- update to 3.3.1

* Sun Sep 26 2004 Than Ngo <than@redhat.com> 3.3.0-2
- cleanup GNOME/KDE menu

* Mon Aug 23 2004 Than Ngo <than@redhat.com> 3.3.0-1
- update to 3.3.0

* Wed Aug 11 2004 Than Ngo <than@redhat.com> 3.3.0-0.1.rc2
- update to 3.3.0 rc2

* Tue Aug 10 2004 Than Ngo <than@redhat.com> 6:3.3.0-0.1.rc1
- update to 3.3.0 rc1

* Mon Jun 21 2004 Than Ngo <than@redhat.com> 6:3.2.3-1
- update to 3.2.3

* Thu May 06 2004 Than Ngo <than@redhat.com> 6:3.2.2-3
- cleanup GNOME/KDE menu

* Sun May 02 2004 Than Ngo <than@redhat.com> 6:3.2.2-2
- fix "Extract here" for tar.gz, #122048
- don't show some KDE apps in GNOME, #117271

* Wed Apr 14 2004 Than Ngo <than@redhat.com> 6:3.2.2-1
- update to 3.2.2

* Mon Mar 29 2004 Than Ngo <than@redhat.com> 3.2.1-1.1
- cleanup KDE/GNOME menus

* Sun Mar 07 2004 Than Ngo <than@redhat.com> 6:3.2.1-1
- 3.2.1 release

* Tue Mar 02 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Wed Feb 25 2004 Than Ngo <than@redhat.com> 6:3.2.0-1.2
- gcc 3.4 build problem

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Wed Feb 11 2004 Than Ngo <than@redhat.com> 6:3.2.0-0.1
- 3.2.0 release
- built against qt 3.3.0

* Thu Jan 22 2004 Than Ngo <than@redhat.com> 6:3.1.95-0.1
- 3.2 RC1

* Mon Dec 01 2003 Than Ngo <than@redhat.com> 6:3.1.94-0.1
- KDE 3.2 Beta2

* Wed Nov 12 2003 Than Ngo <than@redhat.com> 6:3.1.93-0.1
- KDE 3.2 Beta1
- cleanup specfile

* Wed Oct 01 2003 Than Ngo <than@redhat.com> 6:3.1.4-1
- 3.1.4
- add Prereq: /sbin/ldconfig
- remove kdeutils-3.1.3-gcc33.patch, which is in upstream

* Wed Aug 13 2003 Than Ngo <than@redhat.com> 6:3.1.3-3
- fix build problem with gcc 3.3

* Tue Aug 12 2003 Than Ngo <than@redhat.com> 6:3.1.3-2
- rebuilt

* Tue Aug 12 2003 Than Ngo <than@redhat.com> 6:3.1.3-1
- 3.1.3

* Wed Jun 25 2003 Than Ngo <than@redhat.com> 3.1.2-4
- rebuilt

* Wed Jun 04 2003 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue May 20 2003 Than Ngo <than@redhat.com> 3.1.2-2
- 3.1.2

* Tue Apr  8 2003 Than Ngo <than@redhat.com> 3.1.1-2
- fixed package description #53035

* Wed Mar 19 2003 Than Ngo <than@redhat.com> 3.1.1-1
- 3.1.1

* Mon Feb 24 2003 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Sun Feb 23 2003 Than Ngo <than@redhat.com> 3.1-3
- requires kdelibs/kdebase instead kdelib-devel/kdebase-devel

* Fri Feb 21 2003 Than Ngo <than@redhat.com> 3.1-2
- get rid of gcc path from dependency_libs

* Tue Jan 28 2003 Than Ngo <than@redhat.com> 3.1-1
- 3.1 release

* Sat Nov 30 2002 Than Ngo <than@redhat.com> 3.1-0.2
- desktop issues
- get rid of sub packages
- add new kdeutils-devel

* Thu Nov 28 2002 Than Ngo <than@redhat.com> 3.1-0.1
- update to 3.1 rc4

* Sun Nov 10 2002 Than Ngo <than@redhat.com> 3.0.5-1
- update to 3.0.5

* Tue Oct 15 2002 Than Ngo <than@redhat.com> 3.0.4-1
- 3.0.4

* Sat Aug 31 2002 Than Ngo <than@redhat.com> 3.0.3-3
- fix Configure... menu entry in Klaptop applet

* Mon Aug 19 2002 Karsten Hopp <karsten@redhat.de>
- Skip LABEL entries in /etc/FSTAB until kdf can handle them
  The mounts show up with their device name instead (#71063)

* Mon Aug 12 2002 Than Ngo <than@redhat.com> 3.0.3-1
- 3.0.3
- build using gcc-3.2-0.3

* Thu Aug  8 2002 Than Ngo <than@redhat.com> 3.0.2-4
- desktop files issue (bug #67304,67305)

* Tue Jul 23 2002 Tim Powers <timp@redhat.com> 3.0.2-3
- build using gcc-3.2-0.1

* Sat Jul 20 2002 Than Ngo <than@redhat.com> 3.0.2-2
- fix desktop files issue

* Tue Jul 09 2002 Than Ngo <than@redhat.com> 3.0.2-1
- 3.0.2
- use desktop-file-install

* Fri Jun 21 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Thu May 23 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Tue May 14 2002 Bernhard Rosenkraenzer <bero@redhat.com> 3.0.1-1
- 3.0.1

* Wed Apr 17 2002 Bernhard Rosenkraenzer <bero@redhat.com> 3.0.0-4
- Rebuild with changed sonames

* Tue Apr 16 2002 Bernhard Rosenkraenzer <bero@redhat.com> 3.0.0-3
- Add prompt for overwriting files in kedit (#59321)

* Tue Apr  2 2002 Bernhard Rosenkraenzer <bero@redhat.com> 3.0.0-2
- Fix updating from 2.x (#62259)

* Wed Mar 27 2002 Bernhard Rosenkraenzer <bero@redhat.com> 3.0.0-1
- 3.0.0 final

* Wed Mar 21 2002 Bernhard Rosenkraenzer <bero@redhat.com> 3.0.0-0.cvs20020321.1
- kpm is now fully in kdebase; remove spec file hacks

* Wed Mar  6 2002 Bernhard Rosenkraenzer <bero@redhat.com> 3.0.0-0.cvs20020306.1
- Rename subpackages

* Thu Jan 31 2002 Bernhard Rosenkraenzer <bero@redhat.com> 3.0.0-0.cvs20020131.1
- Update, remove kpm (it's in kdebase now)

* Tue Jan 22 2002 Bernhard Rosenkraenzer <bero@redhat.com> 3.0.0-0.cvs20020122.1
- Fix bug #58658

* Thu Jan 17 2002 Bernhard Rosenkraenzer <bero@redhat.com> 3.0.0-0.cvs20020117.1
- Build with new kdelibs, update

* Thu Dec 27 2001 Bernhard Rosenkraenzer <bero@redhat.com> 3.0.0-0.cvs20011227.1
- Update
- Split into subpackages

* Tue Jul 24 2001 Bernhard Rosenkraenzer <bero@redhat.com> 2.2-0.cvs20010724.1
- Remove efax from the package, we're shipping it separately
- Update

* Sun Jul 22 2001 Bernhard Rosenkraenzer <bero@redhat.com> 2.2-0.cvs20010722.1
- Update
- Make symlinks relative

* Wed Feb 21 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- 2.1-respin

* Tue Feb 20 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- 2.1

* Mon Feb 12 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix up detection of PCMCIA sockets

* Tue Feb  6 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Get rid of the libkdefakes.so.0 dependency

* Mon Jan 22 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Update

* Wed Dec 20 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Update to CVS
- Don't exclude ia64 anymore

* Mon Oct 23 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 2.0 final

* Wed Oct  4 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 2.0

* Thu Aug 24 2000 Than Ngo <than@redhat.com>
- update to kdeutils-1.93

* Mon Aug  7 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- new version

* Tue Jul 25 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- new snapshot
- turn off SMP build for kfloppy (broken Makefiles)

* Tue Jul 18 2000 Than Ngo <than@redhat.de>
- rebuilt against gcc-2.96-40 and glibc-2.1.92-14
- don't use make -j, it is broken

* Sun Jul 16 2000 Than Ngo <than@redhat.de>
- use gcc 2.96
- new snapshot

* Fri Jun 23 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Update Epoch

* Tue Jun 20 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- new snapshot
- ExcludeArch: ia64

* Thu Apr  6 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Require and BuildPrereq kdebase - kfind uses libkonq.
- new snapshot

* Mon Mar 20 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 2.0 snapshot

* Tue Feb 29 2000 Preston Brown <pbrown@redhat.com>
- we don't support lp or lprng in 6.x, use lpr as spooler in klpq.
- specific requires for zip and unzip for ark.

* Sat Jan  8 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- KDE_1_1_BRANCH
- rebuild for 6.2

* Fri Sep 24 1999 Preston Brown <pbrown@redhat.com>
- mark docs files as such.

* Thu Sep 09 1999 Preston Brown <pbrown@redhat.com>
- kde 1.1.2 release.

* Fri Jun 11 1999 Preston Brown <pbrown@redhat.com>
- snapshot, includes kde 1.1.1 + fixes

* Mon Apr 19 1999 Preston Brown <pbrown@redhat.com>
- last snapshot before release

* Fri Apr 16 1999 Preston Brown <pbrown@redhat.com>
- today's snapshot provides kpm and kwrite fixes.

* Mon Apr 12 1999 Preston Brown <pbrown@redhat.com>
- latest stable snapshot

* Wed Feb 24 1999 Preston Brown <pbrown@redhat.com>
- Injected new description and group.

* Mon Feb 08 1999 Preston Brown <pbrown@redhat.com>
- upgraded to KDE 1.1 final.

* Mon Jan 18 1999 Preston Brown <pbrown@redhat.com>
- updated macros to be RPM 3.0 compliant, removed redhat dependency.

* Wed Jan 06 1999 Preston Brown <pbrown@redhat.com>
- re-merged in changes from Duncan Haldane







